( cd opt/kde/share/doc/HTML/fr/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ark ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kig ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ktuberling ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/amor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/karm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kate ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdvi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kget ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kgpg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmag ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmid ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmix ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kodo ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kolf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpdf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/korn ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kppp ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/krec ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/krfb ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kscd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksim ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/lisa ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kxkb ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kalzium ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/katomic ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksysguard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbounce ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdearch ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdearch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdelirc/kcmlirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdelirc/irkick ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbattleship ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kaboodle ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/knewsticker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khangman ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kfloppy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/cervisia ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khexedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpercentage ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kandy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcalc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdesu ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcron ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdict ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kfind ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kjots ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmail ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmoon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/knode ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kooka ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksame ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksirc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksysv ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ktron ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kuser ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kview ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kwin4 ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/lskat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/klipper ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmousetool ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kompare ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kontact ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konsole ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpackage ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kshisen ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksirtet ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konquest ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kturtle ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kverbos ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kwallet ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kweather ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kwuftpd ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kioslave ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kxconfig ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/fr/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/crashes ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/babel ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/kuick ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/webarchiver ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/domtreeviewer ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/smbmounter ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/imgallery ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/khtmlsettings ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/validators ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/fsview ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/uachanger ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/mediaplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/dirfilter ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbabel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kamera ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdeprint ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kasteroids ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kbruch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/keduca ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kgamma ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kicker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/klines ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmines ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmouth ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmplot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/knotes ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kopete ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpoker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kruler ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ktalkd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksnake ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kspell ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kstars ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ktimer ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ktouch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kwrite ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kreversi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/noatun ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksplashml ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kblackbox ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kcharselect ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/quanta ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kuickshow ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kiconedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/klettres ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kghostview ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/klickety ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kleopatra ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kenolaba ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kworldclock ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/ksokoban ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kteatime ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kmathtool ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/konqueror ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/korganizer ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/fr/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/atlantik ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
